summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--state/state.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/state/state.go b/state/state.go
index 8ad12e3..109e4d1 100644
--- a/state/state.go
+++ b/state/state.go
@@ -5,8 +5,9 @@ package state
// Contains the result of processing a Feed.
type FeedResult struct {
- FeedId string // Feed's identifier
- Err error // Set on error
+ FeedId string // Feed's identifier
+ FeedResult string // Feed result
+ Err error // Set on error
}
// Contains the result of processing an Entry.